@def foo(): ...
@
def foo(): ...
@@
def foo(): ...
@test
@
class Test
